==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/OperatorSelectorClosingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OperatorSelectorClosingEventArgsDescription } from "./OperatorSelectorClosingEventArgsDescription";
/**
 * @hidden
 */
export let OperatorSelectorClosingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OperatorSelectorClosingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OperatorSelectorClosingEventArgsDescriptionMetadata.a == null) {
                OperatorSelectorClosingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OperatorSelectorClosingEventArgsDescriptionMetadata.c(OperatorSelectorClosingEventArgsDescriptionMetadata.a);
            }
            if (a.j(OperatorSelectorClosingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(OperatorSelectorClosingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OperatorSelectorClosingEventArgsDescriptionMetadata.b(a);
            a.aa("OperatorSelectorClosingEventArgs", () => new OperatorSelectorClosingEventArgsDescription());
            a.z("OperatorSelectorClosingEventArgs", OperatorSelectorClosingEventArgsDescriptionMetadata.a);
        }
    }
    OperatorSelectorClosingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OperatorSelectorClosingEventArgsDescriptionMetadata, 'OperatorSelectorClosingEventArgsDescriptionMetadata');
    OperatorSelectorClosingEventArgsDescriptionMetadata.a = null;
    return OperatorSelectorClosingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/OperatorSelectorClosingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OperatorSelectorClosingEventArgsDescription } from "./OperatorSelectorClosingEventArgsDescription";
/**
 * @hidden
 */
export let OperatorSelectorClosingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OperatorSelectorClosingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OperatorSelectorClosingEventArgsDescriptionMetadata.a == null) {
                OperatorSelectorClosingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OperatorSelectorClosingEventArgsDescriptionMetadata.c(OperatorSelectorClosingEventArgsDescriptionMetadata.a);
            }
            if (a.k(OperatorSelectorClosingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(OperatorSelectorClosingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OperatorSelectorClosingEventArgsDescriptionMetadata.b(a);
            a.ac("OperatorSelectorClosingEventArgs", () => new OperatorSelectorClosingEventArgsDescription());
            a.ab("OperatorSelectorClosingEventArgs", OperatorSelectorClosingEventArgsDescriptionMetadata.a);
        }
    }
    OperatorSelectorClosingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OperatorSelectorClosingEventArgsDescriptionMetadata, 'OperatorSelectorClosingEventArgsDescriptionMetadata');
    OperatorSelectorClosingEventArgsDescriptionMetadata.a = null;
    return OperatorSelectorClosingEventArgsDescriptionMetadata;
})();
